@@ -160,17 +160,12 @@ sub namespaces {
 }
 
 sub namespaces_names {
-	my ($self) = @_;
 	my @result;
 	
-	return $self->{cache}->{namespaces_names} if defined $self->{cache}->{namespaces_names};
-	
 	foreach (@{ $_[0]->namespaces }) {
 		push(@result, $_->[1]);
 	}
 	
-	$self->{cache}->{namespaces_names} = \@result;
-	
 	return \@result;
 }
 
@@ -255,8 +250,6 @@ package #go away indexer!
 use strict;
 use warnings;
 
-our %REGEX_CACHE_CATEGORIES;
-
 sub new {
 	my ($class, $page, $namespaces, $category_anchor, $revision) = @_;
 	my $self = {page => $page, namespaces => $namespaces, category_anchor => $category_anchor};
@@ -318,7 +311,7 @@ sub namespace {
 		return $self->{cache}->{namespace};
 	}
 	
-	if ($title =~ m/^([^:]+):(.*)/o) {
+	if ($title =~ m/^([^:]+):(.*)/) {
 		foreach (@{ $self->{namespaces} } ) {
 			my ($num, $name) = @$_;
 			if ($1 eq $name) {
@@ -340,7 +333,7 @@ sub redirect {
 	
 	return $self->{cache}->{redirect} if defined $self->{cache}->{redirect};
 
-	if ($$text =~ m/^#redirect\s*:?\s*\[\[([^\]]*)\]\]/io) {
+	if ($$text =~ m/^#redirect\s*:?\s*\[\[([^\]]*)\]\]/i) {
 		$ret = $1;
 	} else {
 		$ret = undef;
@@ -360,11 +353,7 @@ sub categories {
 	
 	return $self->{cache}->{categories} if defined $self->{cache}->{categories};
 	
-	if (! defined($REGEX_CACHE_CATEGORIES{$anchor})) {
-		$REGEX_CACHE_CATEGORIES{$anchor} = qr/\[\[$anchor:\s*([^\]]+)\]\]/i;
-	}
-		
-	while($$text =~ /$REGEX_CACHE_CATEGORIES{$anchor}/g) {
+	while($$text =~ m/\[\[$anchor:\s*([^\]]+)\]\]/gi) {
 		my $buf = $1;
 		
 		#deal with the pipe trick
